@@ -9,7 +9,7 @@ use warnings;
 
 use base qw( Tickit::Widget::Tabbed::Tab );
 
-use File::ShareDir qw( dist_file );
+use Circle::FE::Term;
 
 use Module::Pluggable search_path => "Circle::FE::Term::Widget",
                       sub_name => "widgets",
@@ -90,7 +90,7 @@ sub set_level
    my $self = shift;
    my ( $level ) = @_;
 
-   $self->pen->chattr( fg => $self->get_theme_colour( "level$level" ) );
+   $self->pen->chattr( fg => Circle::FE::Term->get_theme_colour( "level$level" ) );
 }
 
 sub set_label_text
@@ -133,62 +133,4 @@ sub activated
    }
 }
 
-# Now read the theme
-my %theme_vars;
-
-{
-   my $theme_filename;
-
-   foreach ( $ENV{CIRCLE_FE_TERM_THEME},
-             "$ENV{HOME}/.circle-fe-term.theme",
-             dist_file( "circle-fe-term", "circle-fe-term.theme" ) ) {
-      defined $_ or next;
-      -e $_ or next;
-
-      $theme_filename = $_;
-      last;
-   }
-
-   defined $theme_filename or die "Cannot find a circle-fe-term.theme";
-
-   open( my $themefh, "<", $theme_filename ) or die "Cannot read $theme_filename - $!";
-
-   while( <$themefh> ) {
-      m/^\s*#/ and next; # skip comments
-      m/^\s*$/ and next; # skip blanks
-
-      m/^(\S*)=(.*)$/ and $theme_vars{$1} = $2, next;
-      print STDERR "Unrecognised theme line: $_";
-   }
-}
-
-sub get_theme_var
-{
-   my $class = shift;
-   my ( $varname ) = @_;
-   return $theme_vars{$varname} if exists $theme_vars{$varname};
-   print STDERR "No such theme variable $varname\n";
-   return undef;
-}
-
-sub translate_theme_colour
-{
-   my $class = shift;
-   my ( $colourname ) = @_;
-
-   return $colourname if $colourname =~ m/^#/; # Literal #rrggbb
-   return $theme_vars{$colourname} if exists $theme_vars{$colourname}; # hope
-   print STDERR "No such theme colour $colourname\n";
-   return undef;
-}
-
-sub get_theme_colour
-{
-   my $class = shift;
-   my ( $varname ) = @_;
-   return $theme_vars{$varname} if exists $theme_vars{$varname};
-   print STDERR "No such theme variable $varname for a colour\n";
-   return undef;
-}
-
 0x55AA;
