@@ -26,4 +26,4 @@ sub build
    return $widget;
 }
 
-1;
+0x55AA;
